@@ -91,7 +91,7 @@ class fMMS_GUI(hildon.Program):
 			print "firstlaunch"
 			self.osso_c = osso.Context("fMMS", "0.1.0", False)
 			note = osso.SystemNote(self.osso_c)
-			firstlaunchmessage = "NOTE: Currently you have to connect manually to the MMS APN when sending and receiving.\n Also, only images is supported as attachment."
+			firstlaunchmessage = "NOTE: Currently you have to connect manually to the MMS APN when sending and receiving.\nAlso, only implemented attachment is image."
 			note.system_note_dialog(firstlaunchmessage , 'notice')
 			self.create_config_dialog()
 			self.config.set_firstlaunch(0)
@@ -146,16 +146,23 @@ class fMMS_GUI(hildon.Program):
 		
 		allVBox = gtk.VBox()
 		
-		
+		self.active_apn_index = 0
 		
 		apnHBox = gtk.HBox()
 		apn_label = gtk.Label("APN:")
-		self.apn = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
+		self.selector = self.create_apn_selector()
+		self.apn = hildon.PickerButton(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+		self.apn.set_selector(self.selector)
+		self.apn.set_active(self.active_apn_index)
+		#self.apn.connect("value-changed", self.apn_picker_changed)
+
+
+		"""self.apn = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
 		apn_nicename = self.config.get_apn_nicename()
 		if apn_nicename != None:
 			self.apn.set_text(self.config.get_apn_nicename())
 		else:
-			self.apn.set_text("Not defined")
+			self.apn.set_text("Not defined")"""
 		apnHBox.pack_start(apn_label, False, True, 0)
 		apnHBox.pack_start(self.apn, True, True, 0)
 		
@@ -219,12 +226,41 @@ class fMMS_GUI(hildon.Program):
 		dialog.destroy()
 		return ret
 		
+	"""def apn_picker_changed(self, button, user_data=None):
+		current_selection = button.get_value()
+		print "Current selection : %s" % (current_selection)"""
+
+	def create_apn_selector(self):
+		#Create a HildonTouchSelector with a single text column
+		selector = hildon.TouchSelector(text = True)
+		
+		apnlist = self.config.get_gprs_apns()
+		
+		currval = self.config.get_apn_nicename()
+		
+		# Populate selector
+		i = 0
+		for apn in apnlist:
+			if apn == currval:
+				self.active_apn_index = i
+			i += 1	
+			# Add item to the column 
+			selector.append_text(apn)
+			
+		selector.center_on_selected()
+		selector.set_active(0, i)
+		# Set selection mode to allow multiple selection
+		selector.set_column_selection_mode(hildon.TOUCH_SELECTOR_SELECTION_MODE_SINGLE)
+		return selector
+		
+		
 	def config_menu_button_clicked(self, action):
 		if action == gtk.RESPONSE_APPLY:
-			ret_setapn = self.config.get_apnid_from_name(self.apn.get_text())
+			print self.apn.get_selector().get_current_text()
+			ret_setapn = self.config.get_apnid_from_name(self.apn.get_selector().get_current_text())
 			if ret_setapn != None:
 				self.config.set_apn(ret_setapn)
-				print "Set apn to: %s" % self.apn.get_text()
+				print "Set apn to: %s" % ret_setapn
 				ret = self.config.set_mmsc(self.mmsc.get_text())
 				print "Set mmsc to %s" % self.mmsc.get_text()
 				self.config.set_phonenumber(self.number.get_text())
@@ -382,7 +418,8 @@ class fMMS_GUI(hildon.Program):
 	""" this function takes the FILENAME, not the full path """
 	def _is_fetched_push(self, filename):
 		if os.path.isdir(self._mmsdir + filename):
-			return True
+			if os.path.isfile(self._mmsdir + filename + "/message"):
+				return True
 		else:
 			return False
 	
@@ -441,6 +478,14 @@ class fMMS_GUI(hildon.Program):
 		print trans_id
 		
 		PUSH = PushHandler()
+		
+		### ugly hack as well
+		# TODO: clean up
+		bus = dbus.SystemBus()
+		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+		interface.SystemNoteInfoprint ("fMMS: Attempting to download MMS from server.")
+		
 		path = PUSH._get_mms_message(url, trans_id)
 		PUSH.decodeMMS(path)
 		
