@@ -163,7 +163,7 @@ class fMMS_GUI(hildon.Program):
 	
 	""" sends the message (no shit?) """
 	def send_mms(self, widget):
-		hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
+		#hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
 		self.osso_c = osso.Context("fMMS", "0.1.0", False)
 		
 		attachment = self.bAttachment.get_label()
@@ -198,6 +198,7 @@ class fMMS_GUI(hildon.Program):
 			(status, reason, output) = sender.sendMMS()
 			### TODO: Clean up and make this look decent
 			message = str(status) + "_" + str(reason)
+		
 			message = message.replace('\0','')
 			reply = str(output).replace('\0','')
 			#print message
