@@ -17,6 +17,7 @@ import urllib
 import httplib
 import conic
 import time
+import socket
 from dbus.mainloop.glib import DBusGMainLoop
 import array
 import fmms_config as fMMSconf
@@ -112,7 +113,6 @@ class PushHandler:
 			interface.Notify("MMS", 0, '', message, sender, choices, {"category": "email-message", "dialog-type": 4, "led-pattern": "PatternCommunicationEmail", "dbus-callback-default": "com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser load_url string:\"" + path + "\""}, -1)
 
 	""" saves the push message so we can reuse it """
-	# TODO: remove hardcoded path
 	def _save_push_message(self, transaction, decodeddata):
 		dirname = self._pushdir
 		if not os.path.isdir(dirname):
@@ -131,7 +131,6 @@ class PushHandler:
 		fname.close()
 
 	""" get the mms message from content-location """
-	# TODO: remove hardcoded proxy
 	def _get_mms_message(self, location, transaction):
 		dirname = self._mmsdir + transaction
 		if not os.path.isdir(dirname):
@@ -140,12 +139,16 @@ class PushHandler:
 			os.makedirs(dirname)
 		print "getting file: ", location
 		try:
-			# TODO: remove hardcoded sleep		
+			# TODO: remove hardcoded sleep
 			con = ConnectToAPN(self._apn_nicename)
 			time.sleep(7)
 			con.connect()
 			
-			# TODO: verify this works
+			# this seems to work like it should
+			# TODO: dont hardcode timeout
+			# god it would be nice with python2.6 for timeout= in urllib2
+			timeout = 20
+			socket.setdefaulttimeout(timeout)
 			(proxyurl, proxyport) = self.config.get_proxy_from_apn()
 			if proxyurl == "" or proxyurl == None:
 				print "connecting without proxy"
@@ -164,13 +167,17 @@ class PushHandler:
 			
 			if(_DBG):
 				print "fetched ", location, " and wrote to file", fp
-			con.disconnect()
+			con.disconnect()	
 			
-			
-		except urllib2.URLError:
+		except Exception, e:
 			print "fetch failed."
+			print e, e.args
 			print "removing dir..."
 			os.rmdir(dirname)
+			bus = dbus.SystemBus()
+			proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+			interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+			interface.SystemNoteInfoprint ("fMMS: Failed to download MMS message.")
 			raise
 		return dirname
 
